==> haskell-yesod-form-1.7.9-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-CvavpTABUb62aQqMzkQJ1
key:                  yesod-form-1.7.9-CvavpTABUb62aQqMzkQJ1
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  412625437ca7d0c56a2bdf6cdfd4a5ba
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-CvavpTABUb62aQqMzkQJ1
depends:
    aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS
    attoparsec-0.14.4-BOYjI7Xnyxi2UxSSzbjWOG base-4.17.2.1
    blaze-builder-0.4.4-Lx3iAaL3SPqLsOeZbYO5TI
    blaze-html-0.9.2.0-6qRmvU75P7Y4rwuconQelG
    blaze-markup-0.8.3.0-HOvk3sClrAvE2E2UKocwxZ
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    email-validate-2.3.2.21-4bEwfREtaBC9jsOCh3wej7
    network-uri-2.6.4.2-2wmE2uZDcqIIgHOfFlXQyo
    persistent-2.14.5.1-9LVnSS7zKhe56T8CFfYny0
    resourcet-1.2.6-JgWdYDiOmbEL6WqMsj6qcd
    shakespeare-2.1.3-AktWEFGoRDbKMnUQqifRLM text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-FUHxhH9mDYMACC6LG7bc57
    xss-sanitize-0.3.7.2-EaB6Zk7cdTxDkBuWNXp1Rb
    yesod-core-1.6.27.1-Je5Rdxu2jxwEMdpzOWi3xQ
    yesod-persistent-1.6.0.8-67IfJGjQUu1DL62ZSDB9KO

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.7.9-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-CAqv7aYS2jIDhOOlA1dEtW
key:                  yesod-form-1.7.9-CAqv7aYS2jIDhOOlA1dEtW
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  98199bd24f90b58605d0a0ea6d4f9ce5
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-CAqv7aYS2jIDhOOlA1dEtW
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    attoparsec-0.14.4-AfQEBsI4KfUBbsB9NxUVAd base-4.17.2.1
    blaze-builder-0.4.4-6Kuq6wnWuSiCILCubQnlxM
    blaze-html-0.9.2.0-Dqz1hSF3Pl41AMAbxwq4Fa
    blaze-markup-0.8.3.0-DSAl5fl5qavBMEF3Zc5OIF
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    email-validate-2.3.2.21-I07O7CRSabJ9LNcyjUcmnD
    network-uri-2.6.4.2-4guMK9PpDjI4XiQikAf4nE
    persistent-2.14.5.1-HjAuo3GZj1BLrod4y0wlr3
    resourcet-1.2.6-KFdVdoMdUy2HAqiIe2FuFP
    shakespeare-2.1.3-LfEVIncrchJ2i1LBCpCzBy text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-3rFOvZ8NgHlICB5dLUJnHJ
    xss-sanitize-0.3.7.2-4dHoXnNPIQpH6Vc3ulOWbp
    yesod-core-1.6.27.1-DRGKJKdi7VKCRZkw8WUb3u
    yesod-persistent-1.6.0.8-2DQecytM20CLDXMZbIpF1G

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
